/***************************************************************************
    copyright            : (C) 2003-2005 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_STRINGS_H
#define TELLICO_STRINGS_H

namespace Tellico {
  extern const char* errorLoad;
  extern const char* errorWrite;
  extern const char* errorUpload;
  extern const char* errorAppendType;
  extern const char* errorMergeType;
  extern const char* errorImageLoad;
}

#endif
